function [co] = DJensenTsallis_HTsallis_initialization(mult)
%Initialization of the Jensen-Tsallis divergence estimator, defined according to the relation:
%D_JT(f_1,f_2) = D_{JT,alpha}(f_1,f_2) = H_{T,alpha}((y^1+y^2)/2) - [1/2*H_{T,alpha}(y^1) + 1/2*H_{T,alpha}(y^2)], where y^i has density f_i (i=1,2), (y^1+y^2)/2 is the mixture distribution of y^1 and y^2 with 1/2-1/2 weights, and H_{T,alpha} denotes the Tsallis entropy.
%
%Note:
%   1)The estimator is treated as a cost object (co).
%   2)We use the naming convention 'D<name>_initialization' to ease embedding new divergence estimation methods.
%   3)This is a meta method: the Tsallis entropy estimator can arbitrary.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'JensenTsallis_HTsallis';
    co.mult = mult;
    
%other fields:
    co.alpha = 0.95; %alpha \ne 1
    
    co.member_name = 'Tsallis_kNN_k'; %you can change it to any Tsallis entropy estimator
    co.member_co = H_initialization(co.member_name,mult);
    
    co.member_co.alpha = co.alpha; %automatism for setting the parameters (co.alpha) of member_co (co_2) in a <=2 deep meta construction (co_1 -> co_2); otherwise, please set the parameters (co.alpha) in the member_co-s.
